Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(877)

Unified Diff: chrome/browser/themes/browser_theme_pack.h

Issue 12163003: Add FilePath to base namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/task_profiler/task_profiler_data_serializer.h ('k') | chrome/browser/themes/theme_service.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/themes/browser_theme_pack.h
diff --git a/chrome/browser/themes/browser_theme_pack.h b/chrome/browser/themes/browser_theme_pack.h
index d15aeb592441e8e5c3f26ea9579a5282fdcd4f5e..64475666640b04b03414a9c037834ea52addea4c 100644
--- a/chrome/browser/themes/browser_theme_pack.h
+++ b/chrome/browser/themes/browser_theme_pack.h
@@ -18,10 +18,9 @@
#include "ui/base/layout.h"
#include "ui/gfx/color_utils.h"
-class FilePath;
-
namespace base {
class DictionaryValue;
+class FilePath;
class RefCountedMemory;
}
@@ -67,14 +66,14 @@ class BrowserThemePack : public base::RefCountedThreadSafe<
// operation should be relatively fast, as it should be an mmap() and some
// pointer swizzling. Returns NULL on any error attempting to read |path|.
static scoped_refptr<BrowserThemePack> BuildFromDataPack(
- const FilePath& path, const std::string& expected_id);
+ const base::FilePath& path, const std::string& expected_id);
// Builds a data pack on disk at |path| for future quick loading by
// BuildFromDataPack(). Often (but not always) called from the file thread;
// implementation should be threadsafe because neither thread will write to
// |image_memory_| and the worker thread will keep a reference to prevent
// destruction.
- bool WriteToDisk(const FilePath& path) const;
+ bool WriteToDisk(const base::FilePath& path) const;
// If this theme specifies data for the corresponding |id|, return true and
// write the corresponding value to the output parameter. These functions
@@ -112,8 +111,8 @@ class BrowserThemePack : public base::RefCountedThreadSafe<
// The type passed to ui::DataPack::WritePack.
typedef std::map<uint16, base::StringPiece> RawDataForWriting;
- // An association between an id and the FilePath that has the image data.
- typedef std::map<int, FilePath> FilePathMap;
+ // An association between an id and the base::FilePath that has the image data.
+ typedef std::map<int, base::FilePath> FilePathMap;
// Default. Everything is empty.
BrowserThemePack();
@@ -141,7 +140,7 @@ class BrowserThemePack : public base::RefCountedThreadSafe<
// Parses the image names out of an extension.
void ParseImageNamesFromJSON(base::DictionaryValue* images_value,
- const FilePath& images_path,
+ const base::FilePath& images_path,
FilePathMap* file_paths) const;
// Creates the data for |source_images_| from |file_paths|.
« no previous file with comments | « chrome/browser/task_profiler/task_profiler_data_serializer.h ('k') | chrome/browser/themes/theme_service.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698